a 'bibentry' object, list of bibentry
objects, or a character vector of package names
file
output bibtex file. Will automatically append
'.bib' if not added. if 'NULL' will use stdout.
append
a logical indicating that bibtex entries be
added the the file. If FALSE (default), the file is
overwritten.
verbose
a logical to toggle verbosity. If
'file=NULL', verbosity is forced off.
Value
a list of citation information, invisibly
Details
This function is simply a wrapper to the function
write.bib by Renaud Gaujoux. Though that function has
been added to the 'bibtex' package by Romain Francois (a
more sensible place to find it), that version was not
avialble on CRAN at the time of writing.
The 'knitcitations' package automatically extends the use
of this function to be able to write bibtex files from a
string of DOIs, making it valuable for purposes beyond
the citation of packages.